@@ -1,7 +1,7 @@
 package Bencher::Scenario::DateModules::Creation;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-08-27'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -19,6 +19,15 @@ our $scenario = {
             fcall_template => 'DateTime->now',
         },
 
+        {
+            name => 'DateTime::Tiny->new(ymd)',
+            fcall_template => 'DateTime::Tiny->new(year=>2016, month=>4, day=>19)',
+        },
+        {
+            name => 'DateTime::Tiny->now',
+            fcall_template => 'DateTime::Tiny->now',
+        },
+
         {
             name => 'Time::Moment->new(ymd)',
             fcall_template => 'Time::Moment->new(year=>2016, month=>4, day=>19)',
@@ -38,7 +47,7 @@ our $scenario = {
             fcall_template => 'Time::Piece::localtime()',
         },
     ],
-    include_result_size => 1,
+    with_result_size => 1,
 };
 
 1;
@@ -56,7 +65,7 @@ Bencher::Scenario::DateModules::Creation - Benchmark date creation
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::DateModules::Creation (from Perl distribution Bencher-Scenarios-DateModules), released on 2017-01-25.
+This document describes version 0.003 of Bencher::Scenario::DateModules::Creation (from Perl distribution Bencher-Scenarios-DateModules), released on 2017-08-27.
 
 =head1 SYNOPSIS
 
@@ -80,6 +89,8 @@ Version numbers shown below are the versions used when running the sample benchm
 
 L<DateTime> 1.36
 
+L<DateTime::Tiny> 1.06
+
 L<Time::Moment> 0.38
 
 L<Time::Local> 1.2300
@@ -106,6 +117,22 @@ Function call template:
 
 
 
+=item * DateTime::Tiny->new(ymd) (perl_code)
+
+Function call template:
+
+ DateTime::Tiny->new(year=>2016, month=>4, day=>19)
+
+
+
+=item * DateTime::Tiny->now (perl_code)
+
+Function call template:
+
+ DateTime::Tiny->now
+
+
+
 =item * Time::Moment->new(ymd) (perl_code)
 
 Function call template:
@@ -147,30 +174,33 @@ Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2
 Benchmark with default options (C<< bencher -m DateModules::Creation >>):
 
  #table1#
- +------------------------+-----------+-----------+------------+---------+---------+
- | participant            | rate (/s) | time (μs) | vs_slowest |  errors | samples |
- +------------------------+-----------+-----------+------------+---------+---------+
- | DateTime->new(ymd)     |     27000 |     37    |        1   | 5.3e-08 |      20 |
- | DateTime->now          |     27000 |     36    |        1   | 5.3e-08 |      20 |
- | Time::Local::timelocal |     97000 |     10    |        3.6 |   7e-08 |      26 |
- | Time::Piece::localtime |    190000 |      5.1  |        7.2 | 6.5e-09 |      21 |
- | Time::Moment->now      |    670000 |      1.5  |       25   | 1.7e-09 |      20 |
- | Time::Moment->new(ymd) |   2900000 |      0.34 |      110   | 4.3e-10 |      20 |
- +------------------------+-----------+-----------+------------+---------+---------+
+ +--------------------------+-----------+-----------+------------+------------------+---------+---------+
+ | participant              | rate (/s) | time (μs) | vs_slowest | result_size (kB) |  errors | samples |
+ +--------------------------+-----------+-----------+------------+------------------+---------+---------+
+ | DateTime->new(ymd)       |     27000 |    38     |       1    |          22      | 6.5e-08 |      21 |
+ | DateTime->now            |     27000 |    37     |       1    |          22      | 3.9e-08 |      21 |
+ | Time::Local::timelocal   |    113000 |     8.84  |       4.25 |           0.0547 | 3.3e-09 |      20 |
+ | Time::Piece::localtime   |    200000 |     5     |       7.6  |           0.44   | 6.5e-09 |      21 |
+ | DateTime::Tiny->now      |    331000 |     3.02  |      12.4  |           0.625  | 2.5e-09 |      20 |
+ | Time::Moment->now        |    946000 |     1.06  |      35.5  |           0.0879 | 4.2e-10 |      20 |
+ | DateTime::Tiny->new(ymd) |   1700000 |     0.589 |      63.8  |           0.369  | 2.1e-10 |      20 |
+ | Time::Moment->new(ymd)   |   3200000 |     0.31  |     120    |           0.088  | 8.1e-10 |      21 |
+ +--------------------------+-----------+-----------+------------+------------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DateModules::Creation --module-startup >>):
 
  #table2#
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors   | samples |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
- | DateTime            | 11                           | 15                 | 44             |      61   |                   56.1 |        1   |   0.00015 |      20 |
- | Time::Piece         | 1.5                          | 5.1                | 17             |      18   |                   13.1 |        3.4 | 4.4e-05   |      26 |
- | Time::Local         | 1.4                          | 4.7                | 19             |      13   |                    8.1 |        4.7 | 8.4e-05   |      20 |
- | Time::Moment        | 1.4                          | 4.7                | 19             |      11   |                    6.1 |        5.6 | 3.7e-05   |      21 |
- | perl -e1 (baseline) | 11                           | 15                 | 44             |       4.9 |                    0   |       12   | 1.5e-05   |      20 |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+-----------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ | DateTime            | 11.1                         | 15                 | 44.5           |      59.4 |                   53.4 |        1   | 4.5e-05 |      21 |
+ | Time::Piece         | 1.4                          | 4.8                | 19             |      19   |                   13   |        3.2 | 2.7e-05 |      20 |
+ | Time::Local         | 1.4                          | 4.7                | 19             |      14   |                    8   |        4.3 | 3.2e-05 |      20 |
+ | Time::Moment        | 1                            | 4.4                | 16             |      12   |                    6   |        5   | 1.6e-05 |      20 |
+ | DateTime::Tiny      | 1                            | 4.4                | 16             |      10   |                    4   |        6   | 1.9e-05 |      20 |
+ | perl -e1 (baseline) | 11                           | 15                 | 44             |       6   |                    0   |        9.9 | 9.4e-06 |      20 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
