@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::DateModules::Creation;
 
-our $VERSION = 0.002; # VERSION
+our $VERSION = 0.003; # VERSION
 
 our $results = [
   [
@@ -8,52 +8,76 @@ our $results = [
     "OK",
     [
       {
-        errors => 5.3e-08,
+        errors => 6.5e-08,
         participant => "DateTime->new(ymd)",
         rate => 27000,
-        samples => 20,
+        result_size => 22,
+        samples => 21,
+        time => 38,
+        vs_slowest => 1,
+      },
+      {
+        errors => 3.9e-08,
+        participant => "DateTime->now",
+        rate => 27000,
+        result_size => 22,
+        samples => 21,
         time => 37,
         vs_slowest => 1,
       },
       {
-        errors => 5.3e-08,
-        participant => "DateTime->now",
-        rate => 27000,
-        samples => 20,
-        time => 36,
-        vs_slowest => 1,
-      },
-      {
-        errors => 7e-08,
+        errors => 3.3e-09,
         participant => "Time::Local::timelocal",
-        rate => 97000,
-        samples => 26,
-        time => 10,
-        vs_slowest => 3.6,
+        rate => 113000,
+        result_size => 0.0547,
+        samples => 20,
+        time => 8.84,
+        vs_slowest => 4.25,
       },
       {
         errors => 6.5e-09,
         participant => "Time::Piece::localtime",
-        rate => 190000,
+        rate => 200000,
+        result_size => 0.44,
         samples => 21,
-        time => 5.1,
-        vs_slowest => 7.2,
+        time => 5,
+        vs_slowest => 7.6,
       },
       {
-        errors => 1.7e-09,
+        errors => 2.5e-09,
+        participant => "DateTime::Tiny->now",
+        rate => 331000,
+        result_size => 0.625,
+        samples => 20,
+        time => 3.02,
+        vs_slowest => 12.4,
+      },
+      {
+        errors => 4.2e-10,
         participant => "Time::Moment->now",
-        rate => 670000,
+        rate => 946000,
+        result_size => 0.0879,
         samples => 20,
-        time => 1.5,
-        vs_slowest => 25,
+        time => 1.06,
+        vs_slowest => 35.5,
       },
       {
-        errors => 4.3e-10,
-        participant => "Time::Moment->new(ymd)",
-        rate => 2900000,
+        errors => 2.1e-10,
+        participant => "DateTime::Tiny->new(ymd)",
+        rate => 1700000,
+        result_size => 0.369,
         samples => 20,
-        time => 0.34,
-        vs_slowest => 110,
+        time => 0.589,
+        vs_slowest => 63.8,
+      },
+      {
+        errors => 8.1e-10,
+        participant => "Time::Moment->new(ymd)",
+        rate => 3200000,
+        result_size => 0.088,
+        samples => 21,
+        time => 0.31,
+        vs_slowest => 120,
       },
     ],
     {
@@ -63,6 +87,7 @@ our $results = [
                                             scenario_module => "DateModules::Creation",
                                           },
       "func.bencher_version"           => undef,
+      "func.code_startup"              => undef,
       "func.cpu_info"                  => [
                                             {
                                               address_width                => 64,
@@ -176,7 +201,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2771.945,
+                                              speed                        => 2676.406,
                                               stepping                     => 4,
                                             },
                                             {
@@ -291,7 +316,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2747.609,
+                                              speed                        => 2867.046,
                                               stepping                     => 4,
                                             },
                                             {
@@ -406,7 +431,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2675.203,
+                                              speed                        => 2855.617,
                                               stepping                     => 4,
                                             },
                                             {
@@ -521,17 +546,18 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2684.828,
+                                              speed                        => 2867.867,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.153120994567871,
+      "func.elapsed_time"              => 0.214282035827637,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
-                                            "__PACKAGE__"                              => 1.034,
+                                            "__PACKAGE__"                              => "1.040",
                                             "Bencher::Scenario::DateModules::Creation" => undef,
                                             "Benchmark::Dumb"                          => "0.10",
                                             "DateTime"                                 => 1.36,
+                                            "DateTime::Tiny"                           => 1.06,
                                             "Devel::Platform::Info"                    => 0.16,
                                             "perl"                                     => "v5.24.0",
                                             "Sys::Info"                                => 0.78,
@@ -540,7 +566,7 @@ our $results = [
                                             "Time::Piece"                              => 1.31,
                                           },
       "func.note"                      => "Run by Pod::Weaver::Plugin::Bencher::Scenario",
-      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 5]],
+      "func.permute"                   => ["perl", ["perl"], "participant", [0 .. 7]],
       "func.platform_info"             => {
                                             archname => "x86_64",
                                             codename => "rosa",
@@ -566,21 +592,31 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::DateModules::Creation",
-      "func.scenario_module_md5sum"    => "545b4897ca06cdf292907132cabdedfc",
-      "func.scenario_module_mtime"     => 1485329400,
-      "func.scenario_module_sha1sum"   => "e4a76c18a6e75adf10dc69232efb0dfb2e9825e4",
-      "func.scenario_module_sha256sum" => "67bc83f85af563bf5518f1abaab5ee5a0e8ae78ba78508012522e586be0a24fc",
-      "func.time_end"                  => 1485329411.79653,
+      "func.scenario_module_md5sum"    => "2ddce479765e447d07228522edd72640",
+      "func.scenario_module_mtime"     => 1503795907,
+      "func.scenario_module_sha1sum"   => "70518214668cd0ad16db13ddb66e73ad3df07ed8",
+      "func.scenario_module_sha256sum" => "87ea248bd02205bf2d2bb0c451086f900727be92bec9f3a535b696f4470517e9",
+      "func.time_end"                  => 1503796326.4226,
       "func.time_factor"               => 1000000,
-      "func.time_start"                => 1485329411.64341,
-      "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
-      "table.field_units"              => [undef, undef, "/s", "\x{3BC}s"],
+      "func.time_start"                => 1503796326.20832,
+      "table.field_aligns"             => [
+                                            "left",
+                                            "left",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                            "number",
+                                          ],
+      "table.field_units"              => [undef, undef, "/s", "\x{3BC}s", undef, "kB"],
       "table.fields"                   => [
                                             "participant",
                                             "dataset",
                                             "rate",
                                             "time",
                                             "vs_slowest",
+                                            "result_size",
                                             "errors",
                                             "samples",
                                           ],
